fn is_connected(state: BlockStateId, side: &EnumProperty<WallSide>) -> boolExpand description
Whether the wall is connected on the given side.
fn is_connected(state: BlockStateId, side: &EnumProperty<WallSide>) -> boolWhether the wall is connected on the given side.